@@ -126,11 +126,38 @@ contain_glyphs(PangoFont *font, const int glyph_map[128])
   return 1;
 }
 
+static PangoGlyph
+thai_xft_make_glyph (ThaiFontInfo *font_info, unsigned int c)
+{
+  int index;
+  PangoGlyph result;
+
+  switch (font_info->font_set) {
+    case THAI_FONT_ISO10646:index = c; break;
+    case THAI_FONT_TIS:     index = (c & 0x80) ? tis620_0[c & 0x7f] : c; break;
+    case THAI_FONT_TIS_MAC: index = (c & 0x80) ? tis620_1[c & 0x7f] : c; break;
+    case THAI_FONT_TIS_WIN: index = (c & 0x80) ? tis620_2[c & 0x7f] : c; break;
+    default:                index = 0; break;
+  }
+  
+  result = pango_xft_font_get_glyph (font_info->font, index);
+  if (result)
+    return result;
+  else
+    return pango_xft_font_get_unknown_glyph (font_info->font, index);
+}
+
+static PangoGlyph
+thai_xft_make_unknown_glyph (ThaiFontInfo *font_info, unsigned int c)
+{
+  return pango_xft_font_get_unknown_glyph (font_info->font, c);
+}
+
 /* Returns a structure with information we will use to rendering given the
  * #PangoFont. This is computed once per font and cached for later retrieval.
  */
-ThaiFontInfo *
-thai_get_font_info (PangoFont *font)
+static ThaiFontInfo *
+thai_xft_get_font_info (PangoFont *font)
 {
   ThaiFontInfo *font_info;
   GQuark info_id = g_quark_from_string ("thai-font-info");
@@ -155,42 +182,31 @@ thai_get_font_info (PangoFont *font)
       else
         font_info->font_set = THAI_FONT_ISO10646;
   
+      font_info->make_glyph = thai_xft_make_glyph;
+      font_info->make_unknown_glyph = thai_xft_make_unknown_glyph;
+
       g_object_set_qdata_full (G_OBJECT (font), info_id, font_info, (GDestroyNotify)g_free);
     }
 
   return font_info;
 }
 
-PangoGlyph
-thai_make_glyph (ThaiFontInfo *font_info, unsigned int c)
+static void 
+thai_engine_xft_shape (PangoFont        *font,
+		       const char       *text,
+		       gint              length,
+		       PangoAnalysis    *analysis,
+		       PangoGlyphString *glyphs)
 {
-  int index;
-  PangoGlyph result;
+  ThaiFontInfo *font_info;
 
-  switch (font_info->font_set) {
-    case THAI_FONT_ISO10646:index = c; break;
-    case THAI_FONT_TIS:     index = (c & 0x80) ? tis620_0[c & 0x7f] : c; break;
-    case THAI_FONT_TIS_MAC: index = (c & 0x80) ? tis620_1[c & 0x7f] : c; break;
-    case THAI_FONT_TIS_WIN: index = (c & 0x80) ? tis620_2[c & 0x7f] : c; break;
-    default:                index = 0; break;
-  }
-  
-  result = pango_xft_font_get_glyph (font_info->font, index);
-  if (result)
-    return result;
-  else
-    return pango_xft_font_get_unknown_glyph (font_info->font, index);
-}
-
-PangoGlyph
-thai_make_unknown_glyph (ThaiFontInfo *font_info, unsigned int c)
-{
-  return pango_xft_font_get_unknown_glyph (font_info->font, c);
+  font_info = thai_xft_get_font_info (font);
+  thai_engine_shape(font_info, text, length, analysis, glyphs);
 }
 
 static PangoCoverage *
-thai_engine_get_coverage (PangoFont  *font,
-			   PangoLanguage *lang)
+thai_engine_xft_get_coverage (PangoFont  *font,
+			      PangoLanguage *lang)
 {
   return pango_font_get_coverage (font, lang);
 }
@@ -205,8 +221,8 @@ thai_engine_xft_new ()
   result->engine.id = SCRIPT_ENGINE_NAME;
   result->engine.type = PANGO_ENGINE_TYPE_SHAPE;
   result->engine.length = sizeof (result);
-  result->script_shape = thai_engine_shape;
-  result->get_coverage = thai_engine_get_coverage;
+  result->script_shape = thai_engine_xft_shape;
+  result->get_coverage = thai_engine_xft_get_coverage;
 
   return (PangoEngine *)result;
 }
