@@ -21,7 +21,6 @@
 
 #include "config.h"
 
-#include <stdio.h>
 #include <string.h>
 #include <limits.h>
 #include <errno.h>
@@ -47,7 +46,7 @@ struct _PangoSubmap
 struct _PangoMap
 {
   gint n_submaps;
-  PangoSubmap submaps[256];
+  PangoSubmap *submaps;
 };
 
 struct _PangoMapInfo
@@ -157,16 +156,16 @@ pango_engine_pair_get_engine (PangoEnginePair *pair)
 	  module = g_module_open (module_name, 0);
 	  if (!module)
 	    {
-	      fprintf(stderr, "Cannot load module %s: %s\n",
-		      module_name, g_module_error());
+	      g_printerr ("Cannot load module %s: %s\n",
+			  module_name, g_module_error());
 	      return NULL;
 	    }
 	  
 	  g_module_symbol (module, "script_engine_load", (gpointer *) &load);
 	  if (!load)
 	    {
-	      fprintf(stderr, "cannot retrieve script_engine_load from %s: %s\n",
-		      module_name, g_module_error());
+	      g_printerr ("cannot retrieve script_engine_load from %s: %s\n",
+			  module_name, g_module_error());
 	      g_module_close (module);
 	      return NULL;
 	    }
@@ -279,14 +278,14 @@ process_module_file (FILE *module_file)
 	      range = g_new (PangoEngineRange, 1);
 	      if (sscanf(tmp_buf->str, "%d-%d:", &start, &end) != 2)
 		{
-		  fprintf(stderr, "Error reading modules file");
+		  g_printerr ("Error reading modules file");
 		  have_error = TRUE;
 		  goto error;
 		}
 	      q = strchr (tmp_buf->str, ':');
 	      if (!q)
 		{
-		  fprintf(stderr, "Error reading modules file");
+		  g_printerr ( "Error reading modules file");
 		  have_error = TRUE;
 		  goto error;
 		}
@@ -306,7 +305,7 @@ process_module_file (FILE *module_file)
       
       if (i<3)
 	{
-	  fprintf(stderr, "Error reading modules file");
+	  g_printerr ("Error reading modules file");
 	  have_error = TRUE;
 	  goto error;
 	}
@@ -403,6 +402,30 @@ init_modules (void)
   read_modules ();
 }
 
+static PangoSubmap *
+map_get_submap (PangoMap *map,
+		int       index)
+{
+  if (index >= map->n_submaps)
+    {
+      /* Round up to a multiple of 256 */
+      int new_n_submaps = (index + 0x100) & ~0xff;
+      int i;
+      
+      map->submaps = g_renew (PangoSubmap, map->submaps, new_n_submaps);
+      for (i=map->n_submaps; i<new_n_submaps; i++)
+	{
+	  map->submaps[i].is_leaf = TRUE;
+	  map->submaps[i].d.entry.info = NULL;
+	  map->submaps[i].d.entry.is_exact = FALSE;
+	}
+      
+      map->n_submaps = new_n_submaps;
+    }
+
+  return &map->submaps[index];
+}
+
 static void
 map_add_engine (PangoMapInfo    *info,
 		PangoEnginePair *pair)
@@ -425,9 +448,10 @@ map_add_engine (PangoMapInfo    *info,
 	   submap <= pair->info.ranges[i].end / 256;
 	   submap ++)
 	{
+	  PangoSubmap *submap_struct = map_get_submap (map, submap);
 	  gunichar start;
 	  gunichar end;
-	  
+
 	  if (submap == pair->info.ranges[i].start / 256)
 	    start = pair->info.ranges[i].start % 256;
 	  else
@@ -438,26 +462,26 @@ map_add_engine (PangoMapInfo    *info,
 	  else
 	    end = 255;
 	  
-	  if (map->submaps[submap].is_leaf &&
+	  if (submap_struct->is_leaf &&
 	      start == 0 && end == 255)
 	    {
-	      set_entry (&map->submaps[submap].d.entry,
+	      set_entry (&submap_struct->d.entry,
 			 is_exact, &pair->info);
 	    }
 	  else
 	    {
-	      if (map->submaps[submap].is_leaf)
+	      if (submap_struct->is_leaf)
 		{
-		  PangoMapEntry old_entry = map->submaps[submap].d.entry;
+		  PangoMapEntry old_entry = submap_struct->d.entry;
 		  
-		  map->submaps[submap].is_leaf = FALSE;
-		  map->submaps[submap].d.leaves = g_new (PangoMapEntry, 256);
+		  submap_struct->is_leaf = FALSE;
+		  submap_struct->d.leaves = g_new (PangoMapEntry, 256);
 		  for (j=0; j<256; j++)
-		    map->submaps[submap].d.leaves[j] = old_entry;
+		    submap_struct->d.leaves[j] = old_entry;
 		}
 	      
 	      for (j=start; j<=end; j++)
-		set_entry (&map->submaps[submap].d.leaves[j],
+		set_entry (&submap_struct->d.leaves[j],
 			   is_exact, &pair->info);
 	      
 	    }
@@ -489,7 +513,6 @@ map_add_engine_list (PangoMapInfo *info,
 static void
 build_map (PangoMapInfo *info)
 {
-  int i;
   PangoMap *map;
 
   const char *engine_type = g_quark_to_string (info->engine_type_id);
@@ -518,13 +541,8 @@ build_map (PangoMapInfo *info)
     }
   
   info->map = map = g_new (PangoMap, 1);
-  map->n_submaps = 256;
-  for (i=0; i<256; i++)
-    {
-      map->submaps[i].is_leaf = TRUE;
-      map->submaps[i].d.entry.info = NULL;
-      map->submaps[i].d.entry.is_exact = FALSE;
-    }
+  map->submaps = NULL;
+  map->n_submaps = 0;
 
   map_add_engine_list (info, dlloaded_engines, engine_type, render_type);  
   map_add_engine_list (info, registered_engines, engine_type, render_type);  
